# Changelog

All notable changes to this project will be documented in this file.

This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v1.0.0]

### Changed

- Migrated from institute-wide git server to GitHub
- Migrated from Poetry to uv
- Consolidated separate repositories into one package
- Cleaned git history (removed binary files)

### Migration Notes

- Previous parser repository archived at: <https://git.iow.de/CTD-Software/seabirdfilehandler>
- Previous processor repository archived at: <https://git.iow.de/CTD-Software/processing>
- Old history preserved in backup tags
